pub enum KeyGenOption {
UseSeed(Vec<u8>),
FromSecretKey(SecretKey),
}Expand description
The various ways a key can be constructed other than random
Variants
UseSeed(Vec<u8>)
The hash of these bytes will be used as the private key
FromSecretKey(SecretKey)
The actual secret key, used to construct the public key