pub struct DeterministicPublicKey(/* private fields */);Expand description
Used to deterministically generate all other generators given a commitment to a private key This is effectively a BLS signature public key
Implementations
Sourceimpl DeterministicPublicKey
impl DeterministicPublicKey
Sourcepub fn to_bytes_compressed_form(&self) -> [u8; 96]
pub fn to_bytes_compressed_form(&self) -> [u8; 96]
Convert to raw bytes compressed form
Sourcepub fn to_bytes_uncompressed_form(&self) -> [u8; 192]
pub fn to_bytes_uncompressed_form(&self) -> [u8; 192]
Convert to raw bytes uncompressed form
Sourceimpl DeterministicPublicKey
impl DeterministicPublicKey
Sourcepub fn new(option: Option<KeyGenOption>) -> Result<(Self, SecretKey), BBSError>
pub fn new(option: Option<KeyGenOption>) -> Result<(Self, SecretKey), BBSError>
Generates a random Secretkey and only creates the commitment to it
Sourcepub fn to_public_key(&self, message_count: usize) -> Result<PublicKey, BBSError>
pub fn to_public_key(&self, message_count: usize) -> Result<PublicKey, BBSError>
Convert to a normal public key but deterministically derive all the generators using the hash to curve algorithm BLS12381G1_XMD:SHA-256_SSWU_RO denoted as H2C h_0 <- H2C(w || I2OSP(0, 4) || I2OSP(0, 1) || I2OSP(message_count, 4)) h_i <- H2C(w || I2OSP(i, 4) || I2OSP(0, 1) || I2OSP(message_count, 4))